@@ -27,11 +27,7 @@
 #include "src/core/lib/http/httpcli.h"
 #include "src/core/lib/http/parser.h"
 #include "src/core/lib/iomgr/polling_entity.h"
-#include "src/core/lib/security/transport/security_connector.h"
-
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "src/core/lib/security/security_connector/security_connector.h"
 
 struct grpc_http_response;
 
@@ -92,13 +88,12 @@ void grpc_override_well_known_credentials_path_getter(
 #define GRPC_ARG_CHANNEL_CREDENTIALS "grpc.channel_credentials"
 
 typedef struct {
-  void (*destruct)(grpc_exec_ctx* exec_ctx, grpc_channel_credentials* c);
+  void (*destruct)(grpc_channel_credentials* c);
 
   grpc_security_status (*create_security_connector)(
-      grpc_exec_ctx* exec_ctx, grpc_channel_credentials* c,
-      grpc_call_credentials* call_creds, const char* target,
-      const grpc_channel_args* args, grpc_channel_security_connector** sc,
-      grpc_channel_args** new_args);
+      grpc_channel_credentials* c, grpc_call_credentials* call_creds,
+      const char* target, const grpc_channel_args* args,
+      grpc_channel_security_connector** sc, grpc_channel_args** new_args);
 
   grpc_channel_credentials* (*duplicate_without_call_credentials)(
       grpc_channel_credentials* c);
@@ -112,17 +107,16 @@ struct grpc_channel_credentials {
 
 grpc_channel_credentials* grpc_channel_credentials_ref(
     grpc_channel_credentials* creds);
-void grpc_channel_credentials_unref(grpc_exec_ctx* exec_ctx,
-                                    grpc_channel_credentials* creds);
+void grpc_channel_credentials_unref(grpc_channel_credentials* creds);
 
 /* Creates a security connector for the channel. May also create new channel
    args for the channel to be used in place of the passed in const args if
    returned non NULL. In that case the caller is responsible for destroying
    new_args after channel creation. */
 grpc_security_status grpc_channel_credentials_create_security_connector(
-    grpc_exec_ctx* exec_ctx, grpc_channel_credentials* creds,
-    const char* target, const grpc_channel_args* args,
-    grpc_channel_security_connector** sc, grpc_channel_args** new_args);
+    grpc_channel_credentials* creds, const char* target,
+    const grpc_channel_args* args, grpc_channel_security_connector** sc,
+    grpc_channel_args** new_args);
 
 /* Creates a version of the channel credentials without any attached call
    credentials. This can be used in order to open a channel to a non-trusted
@@ -157,22 +151,19 @@ void grpc_credentials_mdelem_array_add(grpc_credentials_mdelem_array* list,
 void grpc_credentials_mdelem_array_append(grpc_credentials_mdelem_array* dst,
                                           grpc_credentials_mdelem_array* src);
 
-void grpc_credentials_mdelem_array_destroy(grpc_exec_ctx* exec_ctx,
-                                           grpc_credentials_mdelem_array* list);
+void grpc_credentials_mdelem_array_destroy(grpc_credentials_mdelem_array* list);
 
 /* --- grpc_call_credentials. --- */
 
 typedef struct {
-  void (*destruct)(grpc_exec_ctx* exec_ctx, grpc_call_credentials* c);
-  bool (*get_request_metadata)(grpc_exec_ctx* exec_ctx,
-                               grpc_call_credentials* c,
+  void (*destruct)(grpc_call_credentials* c);
+  bool (*get_request_metadata)(grpc_call_credentials* c,
                                grpc_polling_entity* pollent,
                                grpc_auth_metadata_context context,
                                grpc_credentials_mdelem_array* md_array,
                                grpc_closure* on_request_metadata,
                                grpc_error** error);
-  void (*cancel_get_request_metadata)(grpc_exec_ctx* exec_ctx,
-                                      grpc_call_credentials* c,
+  void (*cancel_get_request_metadata)(grpc_call_credentials* c,
                                       grpc_credentials_mdelem_array* md_array,
                                       grpc_error* error);
 } grpc_call_credentials_vtable;
@@ -184,39 +175,35 @@ struct grpc_call_credentials {
 };
 
 grpc_call_credentials* grpc_call_credentials_ref(grpc_call_credentials* creds);
-void grpc_call_credentials_unref(grpc_exec_ctx* exec_ctx,
-                                 grpc_call_credentials* creds);
+void grpc_call_credentials_unref(grpc_call_credentials* creds);
 
 /// Returns true if completed synchronously, in which case \a error will
 /// be set to indicate the result.  Otherwise, \a on_request_metadata will
 /// be invoked asynchronously when complete.  \a md_array will be populated
 /// with the resulting metadata once complete.
 bool grpc_call_credentials_get_request_metadata(
-    grpc_exec_ctx* exec_ctx, grpc_call_credentials* creds,
-    grpc_polling_entity* pollent, grpc_auth_metadata_context context,
-    grpc_credentials_mdelem_array* md_array, grpc_closure* on_request_metadata,
-    grpc_error** error);
+    grpc_call_credentials* creds, grpc_polling_entity* pollent,
+    grpc_auth_metadata_context context, grpc_credentials_mdelem_array* md_array,
+    grpc_closure* on_request_metadata, grpc_error** error);
 
 /// Cancels a pending asynchronous operation started by
 /// grpc_call_credentials_get_request_metadata() with the corresponding
 /// value of \a md_array.
 void grpc_call_credentials_cancel_get_request_metadata(
-    grpc_exec_ctx* exec_ctx, grpc_call_credentials* c,
-    grpc_credentials_mdelem_array* md_array, grpc_error* error);
+    grpc_call_credentials* c, grpc_credentials_mdelem_array* md_array,
+    grpc_error* error);
 
 /* Metadata-only credentials with the specified key and value where
    asynchronicity can be simulated for testing. */
 grpc_call_credentials* grpc_md_only_test_credentials_create(
-    grpc_exec_ctx* exec_ctx, const char* md_key, const char* md_value,
-    bool is_async);
+    const char* md_key, const char* md_value, bool is_async);
 
 /* --- grpc_server_credentials. --- */
 
 typedef struct {
-  void (*destruct)(grpc_exec_ctx* exec_ctx, grpc_server_credentials* c);
+  void (*destruct)(grpc_server_credentials* c);
   grpc_security_status (*create_security_connector)(
-      grpc_exec_ctx* exec_ctx, grpc_server_credentials* c,
-      grpc_server_security_connector** sc);
+      grpc_server_credentials* c, grpc_server_security_connector** sc);
 } grpc_server_credentials_vtable;
 
 struct grpc_server_credentials {
@@ -227,14 +214,12 @@ struct grpc_server_credentials {
 };
 
 grpc_security_status grpc_server_credentials_create_security_connector(
-    grpc_exec_ctx* exec_ctx, grpc_server_credentials* creds,
-    grpc_server_security_connector** sc);
+    grpc_server_credentials* creds, grpc_server_security_connector** sc);
 
 grpc_server_credentials* grpc_server_credentials_ref(
     grpc_server_credentials* creds);
 
-void grpc_server_credentials_unref(grpc_exec_ctx* exec_ctx,
-                                   grpc_server_credentials* creds);
+void grpc_server_credentials_unref(grpc_server_credentials* creds);
 
 #define GRPC_SERVER_CREDENTIALS_ARG "grpc.server_credentials"
 
@@ -254,10 +239,6 @@ grpc_credentials_metadata_request* grpc_credentials_metadata_request_create(
     grpc_call_credentials* creds);
 
 void grpc_credentials_metadata_request_destroy(
-    grpc_exec_ctx* exec_ctx, grpc_credentials_metadata_request* r);
-
-#ifdef __cplusplus
-}
-#endif
+    grpc_credentials_metadata_request* r);
 
 #endif /* GRPC_CORE_LIB_SECURITY_CREDENTIALS_CREDENTIALS_H */
